@@ -24,6 +24,7 @@
 #' @importFrom crayon green
 #' @importFrom crayon bgRed
 #' @importFrom robotstxt paths_allowed
+#' @importFrom curl has_internet
 
 
 
@@ -34,6 +35,19 @@ paragraphs_scrap <- function(link,
                              askRobot = FALSE) {
 
 
+  if (missing(link)) {
+    stop("'link' is a mandatory parameter")
+  }
+
+  if (!is.character(contain) && !is.null(contain)) {
+
+    stop("the 'contain' parameter must be passed a character string")
+
+
+  }
+
+
+  ##################### Ask Robot part ###############################################
   if (askRobot) {
     if (paths_allowed(link) == TRUE) {
       message(green("the robot.txt doesn't prohibit scraping this web page"))
@@ -45,41 +59,67 @@ paragraphs_scrap <- function(link,
 
     }
 
-
   }
 
+  ####################################################################################
 
-  data <- link %>%
+
+  tryCatch(
+
+  expr = {
+
+    data <- link %>%
     read_html() %>%
     html_nodes("p") %>%
     html_text()
 
+    if (is.null(contain) & collapse == FALSE) {
+      return(data)
 
-  if (is.null(contain) & collapse == F) {
-    return(data)
+    } else if (is.null(contain) & collapse == TRUE) {
+      return(paste(data, collapse = " "))
+
+    } else if (!is.null(contain) & collapse == FALSE) {
+      return(data[grepl(contain,
+                        data,
+                        ignore.case = !case_sensitive)])
+    } else {
+      message("if you decide to collapse the paragraphs,
+      the contain argument will be ignored")
+      return(paste(data, collapse = " "))
+    }
+
+  },
 
 
-  } else if (is.null(contain) & collapse == T) {
-    return(paste(data, collapse = " "))
+  error = function(cond) {
 
+    if (!has_internet()) {
 
+      message("Please check your internet connexion: ")
 
-  } else if (!is.null(contain) & collapse == F) {
-    return(data[grepl(contain, data, ignore.case = !case_sensitive)])
+      message(cond)
 
+      return(NA)
 
+    } else if (grepl("current working directory", cond) ||
+               grepl("HTTP error 404", cond)) {
 
-  } else {
-    message("if you decide to collapse the paragraphs, the contain argument will be ignored")
+      message(paste0("The URL doesn't seem to be a valid one: ", link))
 
+      message(paste0("Here the original error message: ", cond))
 
-    return(paste(data, collapse = " "))
+      return(NA)
 
+    } else {
 
+      message(paste0("Undefined Error: ", cond))
 
+      return(NA)
+
+    }
   }
 
-
-
+  )
 
 }
