@@ -19,8 +19,7 @@
 #' @export
 #' @importFrom magrittr %>%
 #' @importFrom xml2 read_html
-#' @importFrom rvest html_table
-#' @importFrom purrr pluck
+#' @importFrom rvest html_table pluck
 #' @importFrom robotstxt paths_allowed
 #' @importFrom crayon green
 #' @importFrom crayon bgRed
@@ -29,12 +28,27 @@
 
 
 
-table_scrap <-
-  function(link,
-           choose = 1,
-           header = T,
-           askRobot = FALSE,
-           fill = FALSE) {
+table_scrap <- function(link,
+                        choose = 1,
+                        header = TRUE,
+                        fill = FALSE,
+                        askRobot = FALSE) {
+
+
+if(missing(link)) {
+  stop("'link' is a mandatory parameter")
+}
+
+
+if(!is.character(link)) {
+  stop("'link' parameter must be provided as a character string")
+}
+
+
+if(!is.numeric(choose)){
+  stop(paste0("the 'choose' parameter must be provided as numeric not as "),
+       typeof(choose))
+}
 
 
 ############################## Ask robot part ###################################################
@@ -59,21 +73,22 @@ tryCatch(
 
 expr = {
 
-link %>%
+table <- link %>%
       read_html() %>%
-      html_table(header, fill = fill) %>%
-      purrr::pluck(choose)
+      html_table(header, fill = fill)
+
+chosen_table <- table[[choose]]
+
+return(chosen_table)
 
 
-  }, 
+  },
 
 error = function(cond){
 
-if(!has_internet()){
+      if(!has_internet()){
 
-        message("Please check your internet connexion: ")
-
-        message(cond)
+        message(paste0("Please check your internet connexion: ", cond))
 
         return(NA)
 
@@ -81,11 +96,27 @@ if(!has_internet()){
 
           message(paste0("The URL doesn't seem to be a valid one: ", link))
 
-          message("Here the original error message: ")
-
-          message(cond)
+          message(paste0("Here the original error message: ", cond))
 
           return(NA)
+
+
+      } else if(grepl("subscript out of bounds", cond)) {
+
+        message(
+        "Are you sure that your web page contains more than one HTML table ?"
+          )
+
+        message(paste0("Here the original error message: ", cond))
+
+        return(NA)
+
+      } else {
+
+        message(paste0("Undefined Error: ", cond))
+
+        return(NA)
+
       }
 }
 
